import { __decorate, __metadata } from 'tslib';
import { Component, Injectable, NgModule, ViewChildren, EventEmitter, Input, Output, HostBinding, HostListener, Directive, ElementRef } from '@angular/core';
import { CommonModule } from '@angular/common';
import { Validators, FormBuilder, FormsModule, ReactiveFormsModule } from '@angular/forms';
import UIkit from 'uikit';
import { HttpParams, HttpHeaders, HttpClient, HttpClientModule } from '@angular/common/http';
import { throwError } from 'rxjs/internal/observable/throwError';
import { saveAs } from 'file-saver';
import { map, catchError } from 'rxjs/operators';
import { ActivatedRoute, Router, NavigationEnd, RouterModule } from '@angular/router';
import { NouisliderModule } from 'ng2-nouislider';
import { NgxPaginationModule } from 'ngx-pagination';

let ConfigurationComponent = class ConfigurationComponent {
    constructor() { }
    ngOnInit() {
        // initialize settings
        if (!localStorage.getItem('docname') || localStorage.getItem('docname') === 'undefined') {
            localStorage.setItem('docname', '');
        }
        if (!localStorage.getItem('docsnumber') || localStorage.getItem('docsnumber') === 'undefined') {
            localStorage.setItem('docsnumber', '0');
        }
        if (!localStorage.getItem('profileid') || localStorage.getItem('profileid') === 'undefined') {
            localStorage.setItem('profileid', '');
        }
        if (!localStorage.getItem('poswords') || localStorage.getItem('poswords') === 'undefined') {
            localStorage.setItem('poswords', '{}');
        }
        if (!localStorage.getItem('negwords') || localStorage.getItem('negwords') === 'undefined') {
            localStorage.setItem('negwords', '{}');
        }
        if (!localStorage.getItem('contextprev') || localStorage.getItem('contextprev') === 'undefined') {
            localStorage.setItem('contextprev', '20');
        }
        if (!localStorage.getItem('contextnext') || localStorage.getItem('contextnext') === 'undefined') {
            localStorage.setItem('contextnext', '10');
        }
        if (!localStorage.getItem('wordssplitnum') || localStorage.getItem('wordssplitnum') === 'undefined') {
            localStorage.setItem('wordssplitnum', '1');
        }
        if (!localStorage.getItem('punctuation') || localStorage.getItem('punctuation') === 'undefined') {
            localStorage.setItem('punctuation', '0');
        }
        if (!localStorage.getItem('stopwords') || localStorage.getItem('stopwords') === 'undefined') {
            localStorage.setItem('stopwords', '0');
        }
        if (!localStorage.getItem('lowercase') || localStorage.getItem('lowercase') === 'undefined') {
            localStorage.setItem('lowercase', '0');
        }
        if (!localStorage.getItem('stemming') || localStorage.getItem('stemming') === 'undefined') {
            localStorage.setItem('stemming', '0');
        }
        if (!localStorage.getItem('documentarea') || localStorage.getItem('documentarea') === 'undefined') {
            localStorage.setItem('documentarea', 'full');
        }
    }
    promptToLeave(nextUrl) {
        if (nextUrl.indexOf('upload-content') >= 0 || nextUrl.indexOf('configure-profile') >= 0 || nextUrl.indexOf('save-profile') >= 0) {
            return true;
        }
        else {
            return UIkit.modal.confirm('<span class="uk-text-bold">' +
                'Your changes have not been saved to your Profile!<br>Are you sure you want to leave?</span>', { escClose: true }).then(() => {
                return true;
            }, () => false);
        }
    }
    ngAfterViewInit() {
        // $('#child1').stickySidebar();
        if (document.getElementById('enableStickyBarScript')) {
            document.getElementById('enableStickyBarScript').remove();
        }
        const enableStickyBarScript = document.createElement('script');
        enableStickyBarScript.setAttribute('id', 'enableStickyBarScript');
        enableStickyBarScript.innerHTML = '$(\"#child1\").stickySidebar();\n';
        document.body.appendChild(enableStickyBarScript);
    }
};
ConfigurationComponent = __decorate([
    Component({
        selector: 'app-configuration',
        template: "<app-stepsnvabar></app-stepsnvabar>\n<div id=\"parent\">\n  <app-settings  id=\"child1\" class=\"cm-config-settings-section\"></app-settings>\n  <app-resultspreview id=\"child2\" class=\"cm-margin-medium-left\"></app-resultspreview>\n  <div style=\"clear: both;\"></div>\n</div>\n",
        styles: [""]
    }),
    __metadata("design:paramtypes", [])
], ConfigurationComponent);

class Phrase {
}

// The file contents for the current environment will overwrite these during build.
// The build system defaults to the dev environment which uses `environment.ts`, but if you do
// `ng build --env=prod` then `environment.prod.ts` will be used instead.
// The list of which env maps to which file can be found in `.angular-cli.json`.
const environment = {
    production: false,
    miningbackendserveraddress: 'http://localhost:8081'
};

class Util {
    handleError(err) {
        if (err.error instanceof Error) {
            console.error('Client-side error occured.');
        }
        else {
            console.error('Server-side error occured.');
        }
        console.log(err);
        UIkit.notification({
            message: err.message,
            status: 'danger',
            pos: 'top-center',
            timeout: 0
        });
        return throwError(err || 'Server error');
    }
    getUserId() {
        return localStorage.getItem('user_id');
    }
    getBackendServerAddress() {
        if (localStorage.getItem('mining_backend_address')) {
            return localStorage.getItem('mining_backend_address');
        }
        else {
            return environment.miningbackendserveraddress;
        }
    }
    getIsCommunityManager() {
        return localStorage.getItem('isCommunityManager');
    }
}
/**
 * Saves a file by opening file-save-as dialog in the browser
 * using file-save library.
 * @param blobContent file content as a Blob
 * @param fileName name file should be saved as
 */
const saveFile = (blobContent, fileName) => {
    const blob = new Blob([blobContent], { type: 'application/octet-stream' });
    saveAs(blob, fileName);
};

let ConfigurationService = class ConfigurationService {
    constructor(http) {
        this.http = http;
        this.util = new Util();
        this.userId = '';
        this.backendServerAddress = '';
        this.getDocSamplesUrl = '/getdocsamples';
        this.uploadDocumentsUrl = '/uploaddocuments';
        this.chooseSampleUrl = '/choosedocsample';
        this.alreadyDocumentsUrl = '/alreadydocuments';
        this.runMiningUrl = '/runmining';
        this.prepareSavedProfileUrl = '/preparesavedprofile';
        this.userId = this.util.getUserId();
        this.backendServerAddress = this.util.getBackendServerAddress();
    }
    getDocSamples() {
        return this.http.get(this.backendServerAddress + this.getDocSamplesUrl + `?user=${this.userId}`)
            .pipe(map(data => data['documents']))
            .pipe(catchError(this.util.handleError));
    }
    uploadDocuments(file) {
        const formData = new FormData();
        formData.append('upload', file, file.name);
        formData.append('user', this.userId);
        const params = new HttpParams();
        const options = {
            headers: new HttpHeaders().set('Accept', 'application/json').delete('Content-Type'),
            params: params,
            reportProgress: true
        };
        return this.http.post(this.backendServerAddress + this.uploadDocumentsUrl, formData, options)
            .pipe(map(res => res['data']))
            .pipe(catchError(this.util.handleError));
    }
    chooseDocumentsSample(choise) {
        return this.http.post(this.backendServerAddress + this.chooseSampleUrl, { user: this.userId, docsample: choise })
            .pipe(map(res => res['data']))
            .pipe(catchError(this.util.handleError));
    }
    getLoadedDocumentsNumber() {
        return this.http.get(this.backendServerAddress + this.alreadyDocumentsUrl + `?user=${this.userId}`)
            .pipe(catchError(this.util.handleError));
    }
    runMining(parameters) {
        return this.http.post(this.backendServerAddress + this.runMiningUrl, { user: this.userId, parameters: parameters })
            .pipe(catchError(this.util.handleError));
    }
    saveProfileParameters(parameters) {
        const concepts = localStorage.getItem('concepts');
        return this.http.post(this.backendServerAddress + this.prepareSavedProfileUrl, { user: this.userId, concepts: concepts, parameters: parameters })
            .pipe(catchError(this.util.handleError));
    }
};
ConfigurationService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [HttpClient])
], ConfigurationService);

let SettingsComponent = class SettingsComponent {
    constructor(formBuilder, route, router, configurationService) {
        this.formBuilder = formBuilder;
        this.route = route;
        this.router = router;
        this.configurationService = configurationService;
        this.sliderConfig = {
            connect: [true, false],
            tooltips: [true],
            step: 1,
            range: {
                min: 1,
                max: 20
            },
            pips: {
                mode: 'positions',
                values: [0, 45, 100],
                density: 5,
                stepped: true
            }
        };
        this.customRulesOpen = false;
        this.positivePhrasesArray = [];
        this.negativePhrasesArray = [];
        this.positiveSelectedRow = -1;
        this.negativeSelectedRow = -1;
    }
    ngOnInit() {
        this.positivePhraseForm = this.formBuilder.group({
            phrase: [null, Validators.required],
            weight: [null, [Validators.required, Validators.min(0), Validators.max(100)]],
        });
        this.negativePhraseForm = this.formBuilder.group({
            phrase: [null, Validators.required],
            weight: [null, [Validators.required, Validators.min(0), Validators.max(100)]],
        });
        this.settings = {
            docname: localStorage.getItem('docname'),
            docsnumber: Number.parseInt(localStorage.getItem('docsnumber')),
            profileid: localStorage.getItem('profileid'),
            poswords: localStorage.getItem('poswords'),
            negwords: localStorage.getItem('negwords'),
            contextprev: Number.parseInt(localStorage.getItem('contextprev')),
            contextnext: Number.parseInt(localStorage.getItem('contextnext')),
            wordssplitnum: Number.parseInt(localStorage.getItem('wordssplitnum')),
            punctuation: Number.parseInt(localStorage.getItem('punctuation')),
            stopwords: Number.parseInt(localStorage.getItem('stopwords')),
            lowercase: Number.parseInt(localStorage.getItem('lowercase')),
            stemming: Number.parseInt(localStorage.getItem('stemming')),
            documentarea: localStorage.getItem('documentarea'),
        };
        // show positive phrases
        this.positivePhrasesArray.length = 0;
        const posphrases = JSON.parse(localStorage.getItem('poswords'));
        for (const key in posphrases) {
            if (key) {
                const content = new Phrase();
                content.phrase = key;
                content.weight = posphrases[key];
                this.positivePhrasesArray.push(content);
            }
        }
        // show negative phrases
        this.negativePhrasesArray.length = 0;
        const negphrases = JSON.parse(localStorage.getItem('negwords'));
        for (const key in negphrases) {
            if (key) {
                const content = new Phrase();
                content.phrase = key;
                content.weight = negphrases[key];
                this.negativePhrasesArray.push(content);
            }
        }
    }
    onSliderChange(value) {
        localStorage.setItem('wordssplitnum', value.toString());
    }
    advancedCheckboxChange() {
        if (this.customRulesOpen) {
            this.customRulesOpen = false;
        }
        else {
            this.customRulesOpen = true;
        }
    }
    phraseSubmit(positive) {
        const phrase = new Phrase();
        if (positive) {
            phrase.phrase = this.positivePhraseForm.get('phrase').value;
            phrase.weight = this.positivePhraseForm.get('weight').value;
            this.positivePhrasesArray.push(phrase);
            this.positivePhraseForm.reset();
        }
        else {
            phrase.phrase = this.negativePhraseForm.get('phrase').value;
            phrase.weight = this.negativePhraseForm.get('weight').value;
            this.negativePhrasesArray.push(phrase);
            this.negativePhraseForm.reset();
        }
        this.phrasesChanged(positive);
    }
    bulkPutPrhases(phrases, positive) {
        if (positive) {
            localStorage.setItem('poswords', phrases);
            this.positivePhrasesArray.length = 0;
            const posphrases = JSON.parse(localStorage.getItem('poswords'));
            for (const key in posphrases) {
                if (key) {
                    const content = new Phrase();
                    content.phrase = key;
                    content.weight = posphrases[key];
                    this.positivePhrasesArray.push(content);
                }
            }
        }
        else {
            localStorage.setItem('negwords', phrases);
            this.negativePhrasesArray.length = 0;
            const negphrases = JSON.parse(localStorage.getItem('negwords'));
            for (const key in negphrases) {
                if (key) {
                    const content = new Phrase();
                    content.phrase = key;
                    content.weight = negphrases[key];
                    this.positivePhrasesArray.push(content);
                }
            }
        }
    }
    deletePhrase(index, positive) {
        if (positive) {
            this.positivePhrasesArray.splice(index, 1);
        }
        else {
            this.negativePhrasesArray.splice(index, 1);
        }
        this.phrasesChanged(positive);
    }
    selectPhraseRow(row, positive) {
        if (positive) {
            this.positiveSelectedRow = row;
        }
        else {
            this.negativeSelectedRow = row;
        }
    }
    unselectPhraseRow(positive) {
        if (positive) {
            this.positiveSelectedRow = -1;
        }
        else {
            this.negativeSelectedRow = -1;
        }
    }
    phrasesChanged(positive) {
        const hashmap = {};
        if (positive) {
            this.positivePhrasesArray.forEach(function (element) {
                hashmap[element.phrase] = element.weight;
            });
            localStorage.setItem('poswords', JSON.stringify(hashmap));
        }
        else {
            this.negativePhrasesArray.forEach(function (element) {
                hashmap[element.phrase] = element.weight;
            });
            localStorage.setItem('negwords', JSON.stringify(hashmap));
        }
    }
    contextprevChange(value) {
        if (value < 0 || value > 20) {
            return;
        }
        localStorage.setItem('contextprev', value);
        this.getSettingsFromLocalStorage();
    }
    contextnextChange(value) {
        if (value < 0 || value > 20) {
            return;
        }
        localStorage.setItem('contextnext', value);
        this.getSettingsFromLocalStorage();
    }
    stopwordsCheckBoxChange(value) {
        localStorage.setItem('stopwords', value ? '1' : '0');
        this.settings.stopwords = value ? 1 : 0;
    }
    punctuationCheckBoxChange(value) {
        localStorage.setItem('punctuation', value ? '1' : '0');
        this.settings.punctuation = value ? 1 : 0;
    }
    lowercaseCheckBoxChange(value) {
        localStorage.setItem('lowercase', value ? '1' : '0');
        this.settings.lowercase = value ? 1 : 0;
    }
    stemmingCheckBoxChange(value) {
        localStorage.setItem('stemming', value ? '1' : '0');
        this.settings.stemming = value ? 1 : 0;
    }
    documentAreaChange(value) {
        localStorage.setItem('documentarea', value);
        this.settings.documentarea = value;
    }
    getSettingsFromLocalStorage() {
        return this.settings = {
            docname: localStorage.getItem('docname'),
            docsnumber: Number.parseInt(localStorage.getItem('docsnumber')),
            profileid: localStorage.getItem('profileid'),
            poswords: localStorage.getItem('poswords'),
            negwords: localStorage.getItem('negwords'),
            contextprev: Number.parseInt(localStorage.getItem('contextprev')),
            contextnext: Number.parseInt(localStorage.getItem('contextnext')),
            wordssplitnum: Number.parseInt(localStorage.getItem('wordssplitnum')),
            punctuation: Number.parseInt(localStorage.getItem('punctuation')),
            stopwords: Number.parseInt(localStorage.getItem('stopwords')),
            lowercase: Number.parseInt(localStorage.getItem('lowercase')),
            stemming: Number.parseInt(localStorage.getItem('stemming')),
            documentarea: localStorage.getItem('documentarea')
        };
    }
    saveProfile() {
        this.configurationService.saveProfileParameters(this.getSettingsFromLocalStorage())
            .subscribe(() => this.router.navigate(['../save-profile'], { relativeTo: this.route, queryParamsHandling: 'preserve' }));
    }
};
SettingsComponent = __decorate([
    Component({
        selector: 'app-settings',
        template: "<div id=\"child1-inner\" >\n  <div class=\"cm-easy-config-section\">\n    <h4>Default rules <span class=\"cm-tooltip\" uk-icon=\"icon: info\" title=\"An initial set of <b>default mining rules</b>. Such rules include text preprocessing, length of mining area etc.<br>You can <b>edit these rules</b> by selecting <b>Custom rules</b>.\" uk-tooltip=\"pos: right\"></span></h4>\n    <p class=\"uk-text-small\">Select your mining strategy. Choose between high recall or high precision.</p>\n    <div class=\"uk-text-center uk-flex-middle\" uk-grid>\n      <div class=\"uk-width-auto uk-grid-item-match\">\n        <span>High<br>recall</span>\n      </div>\n      <div class=\"uk-width-expand@m\">\n        <nouislider [config]=\"sliderConfig\" [(ngModel)]=\"settings.wordssplitnum\" (ngModelChange)=\"onSliderChange($event)\"></nouislider>\n      </div>\n      <div class=\"uk-width-auto uk-grid-item-match\">\n        <span>High<br>precision</span>\n      </div>\n    </div>\n  </div>\n  <div class=\"cm-advanced-tools-section\">\n    <!--<label class=\"uk-form-label cm-advaned-tools-label\" for=\"advaned-tools-label\">-->\n      <!--<input [checked]=\"customRulesOpen===true\" (click)=\"advancedCheckboxChange()\"  id=\"advaned-tools-label\" class=\"uk-checkbox\" type=\"checkbox\"> Custom rules-->\n    <!--</label>-->\n    <h4>Custom rules</h4>\n    <div id=\"advaned-tools\" style=\"margin-top: 20px;\">\n      <ul uk-accordion=\"multiple: true\">\n        <li>\n          <div class=\"uk-accordion-title\">\n            <span class=\"uk-text-bold uk-text-uppercase\">Positive phrases</span>\n            <span *ngIf=\"positivePhrasesArray.length > 0\" class=\"uk-text-small uk-margin-small-left\">{{positivePhrasesArray.length}} phrase{{positivePhrasesArray.length===1?'':'s'}}</span>\n          </div>\n          <div class=\"uk-accordion-content\">\n            <p class=\"uk-text-small\">Add phrases that are very <b>likely to be near a match</b>. You can use different <b>weights</b> to divide between <b>important</b> and less important phrases. Phrase can be a valid <b>Regular expression</b></p>\n            <div class=\"cm-phrases-container\">\n              <header>\n                <form [formGroup]=\"positivePhraseForm\" id=\"word-form-pos\" class=\"uk-grid-collapse uk-child-width-expand@s uk-text-center\" uk-grid (ngSubmit)=\"phraseSubmit(true)\">\n                  <!-- <div class=\"cm-number-space uk-width-1-5@m\">#</div> -->\n                  <input class=\"uk-width-expand uk-text-left cm-text-input cm-text-input-phrase\" type=\"text\" id=\"text-pos\" placeholder=\"Phrase\" formControlName=\"phrase\"/>\n                  <input class=\"uk-width-1-5@m uk-text-left cm-text-input cm-text-input-weight\" type=\"number\" name=\"weight\" min=\"0\" max=\"100\" id=\"weight-pos\" placeholder=\"Weight\" formControlName=\"weight\"/>\n                  <input type=\"submit\" class=\"btn uk-width-1-4@m cm-main-button cm-phrases-button\" value=\"Add\" [disabled]=\"!positivePhraseForm.valid\"/>\n                </form>\n                <div class=\"scroll_holder\">\n                  <div class=\"scroller\"></div>\n                </div>\n              </header>\n              <div style=\"position: relative;\"><!--\n                                      <div style=\"position: absolute; left: 0; top: 0; height: 100%; width: 40px; background-color: #fafafa; border-right: 1px solid #e8e8e8;\"></div> -->\n                <ul id=\"word-pos\">\n                  <li class=\"uk-grid-collapse uk-child-width-expand@s\" uk-grid *ngFor=\"let phrase of positivePhrasesArray; let i = index\" [ngClass]=\"{'editing':i===positiveSelectedRow}\">\n                    <div class=\"uk-width-expand uk-text-left cm-text-input phrase\">\n                      <input class=\"uk-textarea\" style=\"word-break: break-word; width:100%\" type=\"text\" [(ngModel)]=\"phrase.phrase\" (change)=\"phrasesChanged(true)\" (focus)=\"selectPhraseRow(i, true)\" (focusout)=\"unselectPhraseRow(true)\">\n                    </div>\n                    <div class=\"uk-width-1-4@m uk-text-left cm-text-input weight\">\n                      <input style=\"width:100%\" type=\"number\" min=\"0\" max=\"100\" [(ngModel)]=\"phrase.weight\" (change)=\"phrasesChanged(true)\" (focus)=\"selectPhraseRow(i, true)\" (focusout)=\"unselectPhraseRow(true)\">\n                    </div>\n                    <div class=\"uk-width-1-4@m uk-text-center erase\"><a class=\"uk-icon-link\" uk-icon=\"icon: trash\" contenteditable=\"false\" (click)=\"deletePhrase(i,true)\"></a></div>\n                  </li>\n                </ul>\n              </div>\n              <footer class=\"positive\">\n                <div class=\"uk-grid-collapse uk-child-width-expand@s\" uk-grid>\n                  <div>\n                    <span class=\"count uk-text-middle\" id=\"count-pos\">{{positivePhrasesArray.length}}</span>\n                    <span class=\"uk-text-middle\"> positive word{{positivePhrasesArray.length!==1 ? 's' : ''}}</span>\n                  </div>\n                </div>\n              </footer>\n            </div>\n          </div>\n        </li>\n        <li>\n          <div class=\"uk-accordion-title\">\n            <span class=\"uk-text-bold uk-text-uppercase\">Negative phrases</span>\n            <span *ngIf=\"negativePhrasesArray.length > 0\" class=\"uk-text-small uk-margin-small-left\">{{negativePhrasesArray.length}} phrase{{negativePhrasesArray.length===1?'':'s'}}</span>\n          </div>\n          <div class=\"uk-accordion-content\">\n            <p class=\"uk-text-small\">Add negative phrases. If these phrases are found around the match, this is possibly a <b>false possitive</b>. You can use different <b>weights</b> to assign <b>importance</b>. Phrase can be a valid <b>Regular expression</b></p>\n            <div class=\"word-container\">\n              <div class=\"cm-phrases-container\">\n                <header>\n                  <form [formGroup]=\"negativePhraseForm\" class=\"uk-grid-collapse uk-child-width-expand@s uk-text-center\" id=\"word-form-neg\" uk-grid (ngSubmit)=\"phraseSubmit(false)\">\n                    <!-- <div class=\"cm-number-space uk-width-1-5@m\">#</div> -->\n                    <input class=\"uk-width-expand uk-text-left cm-text-input cm-text-input-phrase\" type=\"text\" id=\"text-neg\" placeholder=\"Phrase\" formControlName=\"phrase\"/>\n                    <input class=\"uk-width-1-5@m uk-text-left cm-text-input cm-text-input-weight\" type=\"number\" name=\"weight\" min=\"0\" max=\"100\" id=\"weight-neg\" placeholder=\"Weight\" formControlName=\"weight\"/>\n                    <input type=\"submit\" class=\"btn uk-width-1-4@m cm-main-button cm-phrases-button\" value=\"Add\" [disabled]=\"!negativePhraseForm.valid\"/>\n                  </form>\n                  <div class=\"scroll_holder\">\n                    <div class=\"scroller\"></div>\n                  </div>\n                </header>\n                <div style=\"position: relative;\">\n                  <!-- <div style=\"position: absolute; left: 0; top: 0; height: 100%; width: 40px; background-color: #fafafa; border-right: 1px solid #e8e8e8;\"></div> -->\n                  <ul id=\"word-neg\">\n                    <li class=\"uk-grid-collapse uk-child-width-expand@s\" uk-grid *ngFor=\"let phrase of negativePhrasesArray; let i = index\" [ngClass]=\"{'editing':i===negativeSelectedRow}\">\n                      <div class=\"uk-width-expand uk-text-left cm-text-input phrase\">\n                        <input class=\"uk-textarea\" style=\"word-break: break-word; width:100%\" type=\"text\" [(ngModel)]=\"phrase.phrase\" (change)=\"phrasesChanged(false)\" (focus)=\"selectPhraseRow(i, false)\" (focusout)=\"unselectPhraseRow(false)\">\n                      </div>\n                      <div class=\"uk-width-1-4@m uk-text-left cm-text-input weight\">\n                        <input style=\"width:100%\" type=\"number\" min=\"0\" max=\"100\" [(ngModel)]=\"phrase.weight\" (change)=\"phrasesChanged(false)\" (focus)=\"selectPhraseRow(i, false)\" (focusout)=\"unselectPhraseRow(false)\">\n                      </div>\n                      <div class=\"uk-width-1-4@m uk-text-center erase\"><a class=\"uk-icon-link\" uk-icon=\"icon: trash\" contenteditable=\"false\" (click)=\"deletePhrase(i,false)\"></a></div>\n                    </li>\n                  </ul>\n                </div>\n                <footer class=\"negative\">\n                  <div class=\"uk-grid-collapse uk-child-width-expand@s\" uk-grid>\n                    <div>\n                      <span class=\"count uk-text-middle\" id=\"count-neg\">{{negativePhrasesArray.length}}</span>\n                      <span class=\"uk-text-middle\"> negative word{{negativePhrasesArray.length!==1 ? 's' : ''}}</span>\n                    </div>\n                  </div>\n                </footer>\n              </div>\n            </div>\n          </div>\n        </li>\n        <li>\n          <div class=\"uk-accordion-title\">\n            <span class=\"uk-text-bold uk-text-uppercase\">Text preprocessing</span>\n            <!--<span *ngIf=\"settings.stopwords===1\" class=\"uk-text-small uk-margin-small-left\">stopwords</span>-->\n            <!--<span *ngIf=\"settings.punctuation===1\" class=\"uk-text-small uk-margin-small-left\">punctuation</span>-->\n          </div>\n          <div class=\"uk-accordion-content\">\n            <p class=\"uk-text-small\">Select among the following text preprocessing steps.</p>\n            <form class=\"uk-form-stacked\">\n              <div class=\"uk-margin\">\n                <label class=\"uk-form-label\" for=\"stop-words-filter\"><input id=\"stop-words-filter\" class=\"uk-checkbox\" type=\"checkbox\" [checked]=\"settings.stopwords===1\" (change)=\"stopwordsCheckBoxChange($event.target.checked)\"> Stopword removal <span class=\"cm-tooltip\" uk-icon=\"icon: info\" title=\"<b>Remove</b> common words (e.g., <b>articles</b> like an, the etc., <b>prepositions</b> like after, to etc.)\" uk-tooltip=\"pos: right\"></span></label>\n              </div>\n              <div class=\"uk-margin\">\n                <label class=\"uk-form-label\" for=\"punctuation-filter\"><input id=\"punctuation-filter\" class=\"uk-checkbox\" type=\"checkbox\" [checked]=\"settings.punctuation===1\" (change)=\"punctuationCheckBoxChange($event.target.checked)\"> Punctuation removal</label>\n              </div>\n              <div class=\"uk-margin\">\n                <label class=\"uk-form-label\" for=\"lowercase-filter\"><input id=\"lowercase-filter\" class=\"uk-checkbox\" type=\"checkbox\" [checked]=\"settings.lowercase===1\" (change)=\"lowercaseCheckBoxChange($event.target.checked)\"> Convert to lower case</label>\n              </div>\n              <div class=\"uk-margin\">\n                <label class=\"uk-form-label\" for=\"stemming-filter\"><input id=\"stemming-filter\" class=\"uk-checkbox\" type=\"checkbox\" [checked]=\"settings.stemming===1\" (change)=\"stemmingCheckBoxChange($event.target.checked)\"> Word stemming <span class=\"cm-tooltip\" uk-icon=\"icon: info\" title=\"Stemming is a process of text normalisation, in which the <b>variant forms of a word are reduced to a common form</b>, for <b>example</b>:<br>connection, connections, connective, connected, connecting<br><b>are reduced to connect</b>\" uk-tooltip=\"pos: right\"></span></label>\n              </div>\n            </form>\n          </div>\n        </li>\n        <li>\n          <div class=\"uk-accordion-title\">\n            <span class=\"uk-text-bold uk-text-uppercase\">Document section</span>\n            <span *ngIf=\"settings.documentarea==='acknowledgment'\" class=\"uk-text-small uk-margin-small-left\">acknowledgment</span>\n            <span *ngIf=\"settings.documentarea==='citations'\" class=\"uk-text-small uk-margin-small-left\">citations</span>\n          </div>\n          <div class=\"uk-accordion-content\">\n            <p class=\"uk-text-small\">Select the part of the document that will be processed.</p>\n            <form class=\"uk-form-stacked\">\n              <div class=\"uk-form-controls\">\n                <div class=\"uk-margin-small\">\n                  <label class=\"uk-form-label\"><input class=\"uk-radio\" type=\"radio\" name=\"documentarea\" [checked]=\"settings.documentarea==='full'\" (click)=\"documentAreaChange('full')\"> Full document <span class=\"cm-tooltip\" uk-icon=\"icon: info\" title=\"The <b>full document</b> is processed\" uk-tooltip=\"pos: right\"></span></label>\n                </div>\n                <div class=\"uk-margin-small\">\n                  <label class=\"uk-form-label\"><input class=\"uk-radio\" type=\"radio\" name=\"documentarea\" [checked]=\"settings.documentarea==='acknowledgment'\" (click)=\"documentAreaChange('acknowledgment')\"> Acknowledgement section <span class=\"cm-tooltip\" uk-icon=\"icon: info\" title=\"Only the <b>acknowledgment</b> section is processed<br><span class='uk-text-danger'>Experimental feature</span>\" uk-tooltip=\"pos: right\"></span></label>\n                </div>\n                <div class=\"uk-margin-small\">\n                  <label class=\"uk-form-label\"><input class=\"uk-radio\" type=\"radio\" name=\"documentarea\" [checked]=\"settings.documentarea==='citations'\" (click)=\"documentAreaChange('citations')\"> Citations section <span class=\"cm-tooltip\" uk-icon=\"icon: info\" title=\"Only the <b>citations</b> section is processed<br><span class='uk-text-danger'>Experimental feature</span>\" uk-tooltip=\"pos: right\"></span></label>\n                </div>\n              </div>\n            </form>\n          </div>\n        </li>\n        <li>\n          <div class=\"uk-accordion-title\">\n            <span class=\"uk-text-bold uk-text-uppercase\">Mining area size</span>\n            <!--<span *ngIf=\"settings.contextprev !== 20\" class=\"uk-text-small uk-margin-small-left\">before: {{settings.contextprev}}</span>-->\n            <!--<span *ngIf=\"settings.contextnext !== 10\" class=\"uk-text-small uk-margin-small-left\">after: {{settings.contextnext}}</span>-->\n          </div>\n          <div class=\"uk-accordion-content\">\n            <p class=\"uk-text-small\">You may edit the length of the text area that the algorithm uses to decide if a match is a true positive.<br><span class=\"uk-text-danger\">For advanced users only</span></p>\n            <form class=\"\">\n              <div class=\"cm-match-area left\">\n                <label class=\"uk-form-label\" for=\"context-prev-words\">Number of words before the match</label>\n                <div class=\"uk-form-controls\">\n                  <input class=\"uk-input\" type=\"number\" name=\"context-prev-words\" min=\"0\" max=\"50\" id=\"context-prev-words\" placeholder=\"Before match, words\" value=\"20\" [value]=\"settings.contextprev\" (change)=\"contextprevChange($event.target.value)\"/>\n                </div>\n              </div>\n              <div class=\"cm-match-area right cm-margin-medium-bottom\">\n                <label class=\"uk-form-label\" for=\"context-next-words\">Number of words after the match</label>\n                <div class=\"uk-form-controls\">\n                  <input class=\"uk-input\" type=\"number\" name=\"context-next-words\" min=\"0\" max=\"50\" id=\"context-next-words\" placeholder=\"After match, words\" value=\"10\" [value]=\"settings.contextnext\" (change)=\"contextnextChange($event.target.value)\"/>\n                </div>\n              </div>\n            </form>\n          </div>\n        </li>\n      </ul>\n    </div>\n  </div>\n  <!--<hr>-->\n  <!--<button id=\"next-button\" class=\"uk-button cm-button-primary uk-margin-small-top\" (click)=\"saveProfile()\">Save this profile</button>-->\n</div>\n",
        styles: [".uk-accordion-title::after{background-image:url(data:image/svg+xml;charset=utf-8,%3Csvg%20width%3D%2220%22%20height%3D%2220%22%20viewBox%3D%220%200%2020%2020%22%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%3E%20%3Cpolyline%20fill%3D%22none%22%20stroke%3D%22%23000%22%20stroke-width%3D%221.03%22%20points%3D%2216%207%2010%2013%204%207%22%3E%3C%2Fpolyline%3E%3C%2Fsvg%3E)}.uk-open>.uk-accordion-title::after{background-image:url(data:image/svg+xml;charset=utf-8,%3Csvg%20width%3D%2220%22%20height%3D%2220%22%20viewBox%3D%220%200%2020%2020%22%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%3E%20%3Cpolyline%20fill%3D%22none%22%20stroke%3D%22%23000%22%20stroke-width%3D%221.03%22%20points%3D%224%2013%2010%207%2016%2013%22%3E%3C%2Fpolyline%3E%3C%2Fsvg%3E)}"]
    }),
    __metadata("design:paramtypes", [FormBuilder,
        ActivatedRoute,
        Router,
        ConfigurationService])
], SettingsComponent);

class DocumentResult {
}

class Match {
}

let ResultspreviewComponent = class ResultspreviewComponent {
    constructor(route, router, configurationService) {
        this.route = route;
        this.router = router;
        this.configurationService = configurationService;
        this.docSamples = [];
        this.docNameLoaded = '';
        this.documentsLoaded = 0;
        this.runingMining = false;
        this.resultsArray = [];
        this.matches_number = '';
        this.prev_matches_number = '';
    }
    ngOnInit() {
        this.getDocSamples();
        this.getLoadedDocuments();
        this.docNameLoaded = localStorage.getItem('docname');
    }
    getDocSamples() {
        this.configurationService.getDocSamples()
            .subscribe(res => this.docSamples = res);
    }
    getLoadedDocuments() {
        this.configurationService.getLoadedDocumentsNumber()
            .subscribe(res => {
            this.documentsLoaded = res.data;
            localStorage.setItem('docsnumber', res.toString());
            if (res.data > 0) ;
        });
    }
    chooseSample(choice) {
        this.configurationService.chooseDocumentsSample(choice)
            .subscribe(res => {
            this.documentsLoaded = res;
            this.docNameLoaded = choice;
            localStorage.setItem('docname', choice);
            localStorage.setItem('docsnumber', res.toString());
        });
    }
    fileChangeUpload(event) {
        const fileList = event.target.files;
        if (fileList && fileList.length === 1) {
            const file = fileList[0];
            // get new profile data
            this.configurationService.uploadDocuments(file)
                .subscribe(res => {
                this.documentsLoaded = res;
                this.docNameLoaded = file.name;
                localStorage.setItem('docname', file.name);
                localStorage.setItem('docsnumber', res.toString());
            });
        }
    }
    getSettingsFromLocalStorage() {
        return {
            docname: localStorage.getItem('docname'),
            docsnumber: Number.parseInt(localStorage.getItem('docsnumber')),
            profileid: localStorage.getItem('profileid'),
            poswords: localStorage.getItem('poswords'),
            negwords: localStorage.getItem('negwords'),
            contextprev: Number.parseInt(localStorage.getItem('contextprev')),
            contextnext: Number.parseInt(localStorage.getItem('contextnext')),
            wordssplitnum: Number.parseInt(localStorage.getItem('wordssplitnum')),
            punctuation: Number.parseInt(localStorage.getItem('punctuation')),
            stopwords: Number.parseInt(localStorage.getItem('stopwords')),
            lowercase: Number.parseInt(localStorage.getItem('lowercase')),
            stemming: Number.parseInt(localStorage.getItem('stemming')),
            documentarea: localStorage.getItem('documentarea'),
        };
    }
    saveProfile() {
        this.configurationService.saveProfileParameters(this.getSettingsFromLocalStorage())
            .subscribe(() => this.router.navigate(['../save-profile'], { relativeTo: this.route, queryParamsHandling: 'preserve' }));
    }
    highlightInElement(element, text) {
        let elementHtml = element;
        const tags = [];
        const tagLocations = [];
        const htmlTagRegEx = /<{1}\/{0,1}\w+>{1}/;
        // Strip the tags from the elementHtml and keep track of them
        let htmlTag;
        while (htmlTag = elementHtml.match(htmlTagRegEx)) {
            tagLocations[tagLocations.length] = elementHtml.search(htmlTagRegEx);
            tags[tags.length] = htmlTag;
            elementHtml = elementHtml.replace(htmlTag, '');
        }
        // Search for the text in the stripped html
        const textLocation = elementHtml.search(text);
        if (textLocation) {
            // Add the highlight
            const highlightHTMLStart = '<span class="highlight">';
            const highlightHTMLEnd = '</span>';
            elementHtml = elementHtml.replace(text, highlightHTMLStart + text + highlightHTMLEnd);
            // Plug back in the HTML tags
            const textEndLocation = textLocation + text.length;
            for (let i = tagLocations.length - 1; i >= 0; i--) {
                let location = tagLocations[i];
                if (location > textEndLocation) {
                    location += highlightHTMLStart.length + highlightHTMLEnd.length;
                }
                else if (location > textLocation) {
                    location += highlightHTMLStart.length;
                }
                elementHtml = elementHtml.substring(0, location) + tags[i] + elementHtml.substring(location);
            }
        }
        // Update the innerHTML of the element
        element = elementHtml;
        return element;
    }
    runMining() {
        if (this.documentsLoaded) {
            // display wait message
            this.runingMining = true;
            // document.getElementById('wait-spinner-modal-center').addClass("uk-open");
            this.configurationService.runMining(this.getSettingsFromLocalStorage())
                .subscribe(res => {
                // hide wait message
                this.runingMining = false;
                UIkit.modal(document.getElementById('wait-spinner-modal-center')).hide();
                // enable sticky
                UIkit.sticky(document.getElementById('cm-run-test-section'), {
                    top: 25,
                    showOnUp: true,
                    animation: 'uk-animation-slide-top',
                    bottom: '.cm-results-section'
                });
                this.resultsArray.length = 0;
                let matchcounter = 0;
                for (const title in res.matches) {
                    if (title) {
                        const matches = res.matches[title];
                        const resultClass = new DocumentResult();
                        resultClass.docTitle = title;
                        const matchesArray = [];
                        resultClass.matches = matchesArray;
                        for (const values of matches) {
                            const match = new Match();
                            match.match = values.match;
                            match.extraprev = values.extraprev;
                            match.extranext = values.extranext;
                            let context = values.prev + ' ' + values.middle + ' ' + values.next;
                            // hightlight positive words
                            for (const posword in JSON.parse(localStorage.getItem('poswords'))) {
                                const search_regexp = new RegExp(posword, 'g');
                                context = context.replace(search_regexp, function (x) {
                                    return '<span class="positive">' + x + '</span>';
                                });
                            }
                            // hightlight acknowledgment keywords
                            for (const ackn of values.acknmatch) {
                                const search_regexp = new RegExp(ackn.replace(/[\-\[\]\/\{\}\(\)\*\+\?\.\\\^\$\|]/g, '\\$&'), 'g');
                                context = context.replace(search_regexp, '<span class="positive">' + ackn + '</span>');
                            }
                            // hightlight negative words
                            for (const negword in JSON.parse(localStorage.getItem('negwords'))) {
                                const search_regexp = new RegExp(negword, 'g');
                                context = context.replace(search_regexp, function (x) {
                                    return '<span class="negative">' + x + '</span>';
                                });
                            }
                            context = this.highlightInElement(context, values.match);
                            match.context = context;
                            match.matchcounter = ++matchcounter;
                            matchesArray.push(match);
                        }
                        this.resultsArray.push(resultClass);
                    }
                }
                this.prev_matches_number = this.matches_number;
                this.matches_number = matchcounter + '';
            });
        }
    }
};
ResultspreviewComponent = __decorate([
    Component({
        selector: 'app-resultspreview',
        template: "<div class=\"uk-grid-collapse uk-child-width-expand uk-text-middle\" uk-grid>\n  <h4 class=\"cm-margin-medium\">Test area</h4>\n  <div class=\"uk-text-right\">\n    <button id=\"next-button\" class=\"uk-button cm-button-primary uk-margin-small-top\" (click)=\"saveProfile()\">Continue</button>\n  </div>\n</div>\n<div class=\"cm-results-section\">\n  <header id=\"cm-results-section-header\" class=\"uk-container uk-container-expand\">\n    <div class=\"cm-results-controls\">\n      <div class=\"uk-margin\">\n        <p>Select or upload a dataset to test the mining algorithm. Each dataset contains documents from various sources according to its title.</p>\n        <div class=\"uk-grid-collapse uk-child-width-expand\" uk-grid>\n          <!--<form class=\"uk-search uk-search-default uk-width-1-5@m\">-->\n            <!--<span class=\"uk-search-icon-flip\" uk-search-icon></span>-->\n            <!--<input class=\"uk-search-input\" type=\"search\" placeholder=\"Search...\" style=\"background-color:  white;\">-->\n          <!--</form>-->\n          <button *ngIf=\"documentsLoaded>0\" class=\"uk-button cm-button-primary uk-width-auto cm-doc-selected\">{{docNameLoaded}}<span uk-icon=\"icon: check; ratio: 1\"></span></button>\n          <div class=\"uk-width-expand\" uk-slider>\n            <div class=\"uk-position-relative\">\n              <div class=\"uk-slider-container\">\n                <ul class=\"uk-slider-items uk-grid-small\">\n                  <li *ngFor=\"let doc of docSamples\">\n                    <button class=\"uk-button cm-button-examples\" (click)=\"chooseSample(doc.name)\">{{doc.name}}</button>\n                  </li>\n                </ul>\n              </div>\n              <div >\n                <a class=\"uk-position-center-left uk-position-small cm-slidenav cm-slidenav-left\" href=\"#\" uk-slidenav-previous uk-slider-item=\"previous\"></a>\n                <a class=\"uk-position-center-right uk-position-small cm-slidenav cm-slidenav-right\" href=\"#\" uk-slidenav-next uk-slider-item=\"next\"></a>\n              </div>\n            </div>\n          </div>\n        </div>\n        <div class=\"uk-grid-collapse uk-child-width-expand\" uk-grid>\n          <span *ngIf=\"documentsLoaded>0\" class=\"uk-text uk-text-success\" style=\"margin-top: 12px\">{{documentsLoaded}} document{{documentsLoaded===1?'':'s'}} loaded</span>\n          <span *ngIf=\"documentsLoaded<1\" class=\"uk-text uk-text-danger\" style=\"margin-top: 12px\">No documents selected</span>\n          <div class=\"uk-text-right uk-margin-small-top\">\n            <span class=\"uk-text-middle\">or</span>\n            <div uk-form-custom>\n              <input #docupload type=\"file\" (change)=\"fileChangeUpload($event);docupload.value=''\" accept=\".txt,.pdf\">\n              <span class=\"uk-link\">Upload your documents</span>\n            </div>\n              <span class=\"cm-tooltip\" uk-icon=\"icon: info\" title=\"<span class='cm-label cm-label-docs'>PDF</span><span class='cm-label cm-label-docs'>TXT</span><span class='cm-label cm-label-docs'>JSON</span><span class='uk-text uk-text-small cm-coloured-text-meta'><br>maximum 1MB</span><br><br>Upload either a <b>PDF</b> or a <b>TXT</b> file. For <b>multiple documents</b> use valid <b>JSON file with two keys (id, text)</b>\" uk-tooltip=\"pos: right\"></span>\n          </div>\n        </div>\n\n      </div>\n    </div>\n  </header>\n  <div id=\"cm-run-test-section\">\n    <div class=\"uk-display-inline\">\n      <button id=\"run-mining-btn\" class=\"uk-button cm-run-test-button\" [disabled]=\"documentsLoaded<1\" (click)=\"runMining()\">Run rules test</button>\n      <span *ngIf=\"matches_number !== ''\" id=\"results-number\" class=\"cm-coloured-text uk-margin-left uk-text-bottom\">{{matches_number}} matche{{matches_number == '1'?'':'s'}} found</span>\n      <span *ngIf=\"prev_matches_number !== ''\" id=\"results-number-previous\" class=\"cm-text-muted uk-text-bottom\">, {{prev_matches_number}} matche{{prev_matches_number == '1'?'':'s'}} found previously</span>\n    </div>\n  </div>\n  <div id=\"results-section\" class=\"cm-results-rows\">\n    <ul id=\"docs-results\" uk-accordion=\"multiple: true\">\n      <li *ngFor=\"let result of resultsArray;\" class=\"uk-card uk-card-default uk-card-small uk-card-body uk-open\">\n        <h3 class=\"uk-accordion-title\"><span class=\"uk-text-meta\">document:</span> {{result.docTitle}}</h3>\n        <div class=\"uk-accordion-content\" aria-hidden=\"false\">\n          <div *ngFor=\"let match of result.matches\">\n            <div class=\"match\"><span class=\"uk-text-meta\">match #{{match.matchcounter}}:</span> {{match.match}}</div>\n            <p class=\"cm-document-result\">\n              {{match.extraprev}} <span class=\"textwindow\" [innerHTML]=\"match.context\"></span> {{match.extranext}}\n            </p>\n          </div>\n        </div>\n      </li>\n    </ul>\n  </div>\n</div>\n\n<div id=\"wait-spinner-modal-center\" class=\"uk-flex-top\" esc-close=\"false\" bg-close=\"false\" uk-modal [ngClass]=\"{'uk-open':runingMining}\" [style.display]=\"runingMining ? 'flex' : 'none'\">\n  <div class=\"uk-modal-dialog uk-modal-body uk-margin-auto-vertical\">\n    <p class=\"uk-text-center uk-text-middle uk-text-large\">Working on it, please wait... <span uk-spinner></span></p>\n  </div>\n</div>\n",
        styles: [".uk-accordion-title::after{background-image:url(data:image/svg+xml;charset=utf-8,%3Csvg%20width%3D%2220%22%20height%3D%2220%22%20viewBox%3D%220%200%2020%2020%22%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%3E%20%3Cpolyline%20fill%3D%22none%22%20stroke%3D%22%23000%22%20stroke-width%3D%221.03%22%20points%3D%2216%207%2010%2013%204%207%22%3E%3C%2Fpolyline%3E%3C%2Fsvg%3E)}.uk-open>.uk-accordion-title::after{background-image:url(data:image/svg+xml;charset=utf-8,%3Csvg%20width%3D%2220%22%20height%3D%2220%22%20viewBox%3D%220%200%2020%2020%22%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%3E%20%3Cpolyline%20fill%3D%22none%22%20stroke%3D%22%23000%22%20stroke-width%3D%221.03%22%20points%3D%224%2013%2010%207%2016%2013%22%3E%3C%2Fpolyline%3E%3C%2Fsvg%3E)}"]
    }),
    __metadata("design:paramtypes", [ActivatedRoute, Router, ConfigurationService])
], ResultspreviewComponent);

let StepsnvabarComponent = class StepsnvabarComponent {
    constructor(route, router) {
        this.route = route;
        this.router = router;
        this.proccessStep = 0;
        router.events.subscribe((val) => {
            // see also
            if (val instanceof NavigationEnd) {
                this.changeStep(val.urlAfterRedirects);
            }
        });
    }
    ngOnInit() { }
    changeStep(url) {
        if (url.indexOf('mining/upload-content') >= 0) {
            this.proccessStep = 1;
        }
        else if (url.indexOf('mining/configure-profile') >= 0) {
            this.proccessStep = 2;
        }
        else if (url.indexOf('mining/save-profile') >= 0) {
            this.proccessStep = 3;
        }
        else {
            this.proccessStep = 0;
        }
    }
    cancelHandle(proccessStep) {
        if (proccessStep === 3) {
            UIkit.modal.confirm('<span class="uk-text-bold">' +
                'Your changes have not been saved to your Profile!<br>Are you sure you want to leave?</span>', { escClose: true }).then(() => {
                this.router.navigate(['../manage-profiles'], { relativeTo: this.route, queryParamsHandling: 'preserve' });
            }, () => false);
        }
        else {
            this.router.navigate(['../manage-profiles'], { relativeTo: this.route, queryParamsHandling: 'preserve' });
        }
    }
};
StepsnvabarComponent = __decorate([
    Component({
        selector: 'app-stepsnvabar',
        template: "<!--<div *ngIf=\"proccessStep>0\" class=\"uk-flex-inline cm-nav-container\">-->\n  <!--<div class=\"cm-left-box\"><a (click)=\"cancelHandle()\"><button id=\"cancel-main-btn\" class=\"uk-close-large cm-close-btn\" type=\"button\" uk-close></button></a></div>-->\n  <!--<div class=\"cm-navigation cm-nav-toolbar\">-->\n    <!--<ul class=\"uk-subnav uk-subnav-line\">-->\n      <!--<li class=\"cm-nav-li\" [ngClass]=\"{'cm-nav-active':proccessStep===1, 'cm-nav-disabled':proccessStep<1}\">-->\n        <!--<a class=\"cm-nav-a\" [routerLink]=\"proccessStep>1 ? ['/upload-content'] : []\">-->\n          <!--<div class=\"cm-nav-number-container\"><span class=\"cm-nav-number uk-text-middle\">1</span></div>-->\n          <!--<span class=\"cm-nav-title uk-text-middle\">Matching context<br>definition</span>-->\n        <!--</a>-->\n      <!--</li>-->\n      <!--<li class=\"cm-nav-li\" [ngClass]=\"{'cm-nav-active':proccessStep===2, 'cm-nav-disabled':proccessStep<2}\">-->\n        <!--<a class=\"cm-nav-a\" [routerLink]=\"proccessStep>2 ? ['/configure-profile'] : []\">-->\n          <!--<div class=\"cm-nav-number-container\"><span class=\"cm-nav-number uk-text-middle\">2</span></div>-->\n          <!--<span class=\"cm-nav-title uk-text-middle\">Matching proccess<br>configuration</span>-->\n        <!--</a>-->\n      <!--</li>-->\n      <!--<li class=\"cm-nav-li\" [ngClass]=\"{'cm-nav-active':proccessStep===3, 'cm-nav-disabled':proccessStep<3}\">-->\n        <!--<a class=\"cm-nav-a\" [routerLink]=\"proccessStep>3 ? ['/save-profile'] : []\">-->\n          <!--<div class=\"cm-nav-number-container\"><span class=\"cm-nav-number uk-text-middle\">3</span></div>-->\n          <!--<span class=\"cm-nav-title uk-text-middle\">Save your<br>matching profile</span>-->\n        <!--</a>-->\n      <!--</li>-->\n    <!--</ul>-->\n  <!--</div>-->\n<!--</div>-->\n<div class=\"uk-alert uk-alert-primary\">\n  <div><span class=\"uk-margin-small-right uk-icon\" uk-icon=\"warning\"></span>\n    This functionality is not yet fully integrated, stay tuned!\n  </div>\n\n</div>\n<div *ngIf=\"proccessStep>0\" class=\"uk-section uk-section-default\" style=\"padding-bottom: 50px;\">\n  <div class=\"uk-container uk-container-large\">\n    <div class=\"uk-grid-collapse uk-child-width-expand\" uk-grid>\n      <div class=\"cm-nav2 uk-width-expand\">\n        <a class=\"cm-nav2-home\" (click)=\"cancelHandle(proccessStep)\"><span class=\"uk-icon\" uk-icon=\"icon: home\"></span></a>\n        <a class=\"cm-nav2-step\" [ngClass]=\"{'cm-nav2-step-active':proccessStep===1, 'cm-nav2-step-disabled':proccessStep<1}\" [routerLink]=\"proccessStep>1 ? ['../upload-content'] : []\" queryParamsHandling=\"preserve\">Add concepts</a>\n        <a class=\"cm-nav2-step\" [ngClass]=\"{'cm-nav2-step-active':proccessStep===2, 'cm-nav2-step-disabled':proccessStep<2}\" [routerLink]=\"proccessStep>2 ? ['../configure-profile'] : []\" queryParamsHandling=\"preserve\">Configure matching proccess</a>\n        <a class=\"cm-nav2-step\" [ngClass]=\"{'cm-nav2-step-active':proccessStep===3, 'cm-nav2-step-disabled':proccessStep<3}\" [routerLink]=\"proccessStep>3 ? ['../save-profile'] : []\" queryParamsHandling=\"preserve\">Save matching profile</a>\n      </div>\n      <!--<a class=\"uk-width-auto uk-float-right uk-link-muted\" (click)=\"cancelHandle()\" style=\"line-height: 52px;\">-->\n        <!--<span class=\"uk-icon uk-margin-small-right\" uk-icon=\"icon: close\"></span>-->\n        <!--<span class=\"uk-text-middle\">Cancel</span>-->\n      <!--</a>-->\n    </div>\n  </div>\n</div>\n\n",
        styles: [""]
    }),
    __metadata("design:paramtypes", [ActivatedRoute, Router])
], StepsnvabarComponent);

let StepsnavbarModule = class StepsnavbarModule {
};
StepsnavbarModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            RouterModule
        ],
        exports: [
            StepsnvabarComponent
        ],
        declarations: [
            StepsnvabarComponent
        ]
    })
], StepsnavbarModule);

let ConfigurationModule = class ConfigurationModule {
};
ConfigurationModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            FormsModule,
            ReactiveFormsModule,
            StepsnavbarModule,
            NouisliderModule
        ],
        exports: [
            ConfigurationComponent
        ],
        providers: [
            ConfigurationService
        ],
        declarations: [ConfigurationComponent, SettingsComponent, ResultspreviewComponent]
    })
], ConfigurationModule);

let ManageprofilesService = class ManageprofilesService {
    constructor(http) {
        this.http = http;
        this.util = new Util();
        this.userId = '';
        this.backendServerAddress = '';
        this.isCommunityManager = 'false';
        this.initServerHandshake = '/initialhandshake';
        this.getusersProfilesUrl = '/getusersprofiles';
        this.updateProfileStatusUrl = '/updateprofilestatus';
        this.getSavedProfilesUrl = '/getuserprofiles';
        this.downloadProfileUrl = '/downloadprofile';
        this.DeleteuserProfileUrl = '/deleteuserprofile';
        this.createNewProfileUrl = '/createnewprofile';
        this.loadSavedProfileUrl = '/loaduserprofile';
        this.getExampleProfilesUrl = '/getexampleprofiles';
        this.loadExampleProfileUrl = '/loadexampleprofile';
        this.uploadProfileUrl = '/uploadprofile';
        this.notifyProfileUrl = '/notifyforprofile';
        this.userId = this.util.getUserId();
        this.backendServerAddress = this.util.getBackendServerAddress();
        this.isCommunityManager = this.util.getIsCommunityManager();
    }
    initialServerHandshake(communityId) {
        return this.http.get(this.backendServerAddress + this.initServerHandshake + `?user=${this.userId}&communityId=${communityId}`)
            .pipe(catchError(this.util.handleError));
    }
    getUsersProfiles() {
        return this.http.get(this.backendServerAddress + this.getusersProfilesUrl + `?isinadministrators=${this.isCommunityManager}`)
            .pipe(map(data => data['profiles']))
            .pipe(catchError(this.util.handleError));
    }
    updateProfileStatus(userId, profileId, status) {
        return this.http.post(this.backendServerAddress + this.updateProfileStatusUrl, { isinadministrators: this.isCommunityManager, user: userId, id: profileId, status: status })
            .pipe(catchError(this.util.handleError));
    }
    downloadUserProfileAdmin(userId, profileId) {
        return this.http.post(this.backendServerAddress + this.downloadProfileUrl, { user: userId, id: profileId }, { responseType: 'blob' })
            .pipe(catchError(this.util.handleError));
    }
    loadUserProfileAdmin(userId, profileId) {
        return this.http.post(this.backendServerAddress + this.loadSavedProfileUrl, { user: userId, id: profileId })
            .pipe(catchError(this.util.handleError));
    }
    downloadProfile(profileId) {
        return this.http.post(this.backendServerAddress + this.downloadProfileUrl, { user: this.userId, id: profileId }, { responseType: 'blob' })
            .pipe(catchError(this.util.handleError));
    }
    deleteProfile(profileId) {
        return this.http.post(this.backendServerAddress + this.DeleteuserProfileUrl, { user: this.userId, id: profileId })
            .pipe(catchError(this.util.handleError));
    }
    createNewProfile() {
        return this.http.get(this.backendServerAddress + this.createNewProfileUrl + `?user=${this.userId}`)
            .pipe(catchError(this.util.handleError));
    }
    loadSavedProfile(profileId) {
        return this.http.post(this.backendServerAddress + this.loadSavedProfileUrl, { user: this.userId, id: profileId })
            .pipe(catchError(this.util.handleError));
    }
    loadExampleProfile(name) {
        return this.http.post(this.backendServerAddress + this.loadExampleProfileUrl, { user: this.userId, name: name })
            .pipe(catchError(this.util.handleError));
    }
    uploadFile(file) {
        const formData = new FormData();
        formData.append('upload', file, file.name);
        formData.append('user', this.userId);
        const params = new HttpParams();
        const options = {
            headers: new HttpHeaders().set('Accept', 'application/json').delete('Content-Type'),
            params: params,
            reportProgress: true
        };
        return this.http.post(this.backendServerAddress + this.uploadProfileUrl, formData, options)
            .pipe(catchError(this.util.handleError));
    }
    getSavedProfiles() {
        return this.http.get(this.backendServerAddress + this.getSavedProfilesUrl + `?user=${this.userId}`)
            .pipe(map(data => data['profiles']))
            .pipe(catchError(this.util.handleError));
    }
    getExampleProfiles() {
        return this.http.get(this.backendServerAddress + this.getExampleProfilesUrl)
            .pipe(map(data => data['profiles']))
            .pipe(catchError(this.util.handleError));
    }
    notifyProfile(communityId, profileId) {
        return this.http.post(this.backendServerAddress + this.notifyProfileUrl, { community: communityId, user: this.userId, id: profileId })
            .pipe(catchError(this.util.handleError));
    }
};
ManageprofilesService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [HttpClient])
], ManageprofilesService);

let ManageprofilesComponent = class ManageprofilesComponent {
    constructor(manageProfilesService, route, router) {
        this.manageProfilesService = manageProfilesService;
        this.route = route;
        this.router = router;
        // TODO profile table sorting: https://ciphertrick.com/2017/08/01/search-sort-pagination-in-angular/
        this.allUsersProfiles = [];
        this.statusValues = [
            'Processing',
            'Evaluating',
            'On Beta'
        ];
        this.communityId = '';
        this.isCommunityManager = false;
        this.userSavedProfiles = [];
        this.exampleProfiles = [];
        this.allProfiles = {
            id: 'all',
            itemsPerPage: 5,
            currentPage: 1
        };
        this.userProfiles = {
            id: 'user',
            itemsPerPage: 5,
            currentPage: 1
        };
        this.pending = false;
    }
    ngOnInit() {
        this.route.queryParams
            .subscribe(params => {
            // console.log('queryParams', params['communityId']);
            this.communityId = params['communityId'];
            this.initialServerHandshake(this.communityId);
        });
        this.isCommunityManager = this.manageProfilesService.isCommunityManager === 'true';
    }
    initialServerHandshake(communityId) {
        this.manageProfilesService.initialServerHandshake(communityId)
            .subscribe(() => {
            if (this.isCommunityManager) {
                this.getAllUsersProfiles();
            }
            this.getSavedProfiles();
            this.getExampleProfiles();
        });
    }
    getAllUsersProfiles() {
        this.manageProfilesService.getUsersProfiles()
            .subscribe(res => {
            if (res) {
                this.allUsersProfiles = res;
            }
        });
    }
    getSavedProfiles() {
        this.manageProfilesService.getSavedProfiles()
            .subscribe(res => {
            if (res) {
                this.userSavedProfiles = res;
            }
        });
    }
    getExampleProfiles() {
        this.manageProfilesService.getExampleProfiles()
            .subscribe(res => {
            console.log(res);
            this.exampleProfiles = res;
        });
    }
    clearLocalStorage() {
        // clear localstorage values
        localStorage.removeItem('grants');
        localStorage.removeItem('profilename');
        localStorage.removeItem('profileid');
        localStorage.removeItem('docname');
        localStorage.removeItem('docsnumber');
        localStorage.removeItem('concepts');
        localStorage.removeItem('poswords');
        localStorage.removeItem('negwords');
        localStorage.removeItem('contextprev');
        localStorage.removeItem('contextmiddle');
        localStorage.removeItem('contextnext');
        localStorage.removeItem('wordssplitnum');
        localStorage.removeItem('punctuation');
        localStorage.removeItem('stopwords');
        localStorage.removeItem('lowercase');
        localStorage.removeItem('stemming');
        localStorage.removeItem('documentarea');
    }
    loadUserProfileAdmin(userId, profileId, name) {
        this.manageProfilesService.loadUserProfileAdmin(userId, profileId)
            .subscribe(res => {
            // clear localstorage values
            this.clearLocalStorage();
            // store to client all profile data
            localStorage.setItem('docname', res.docname);
            localStorage.setItem('docsnumber', res.docsnumber);
            localStorage.setItem('concepts', res.concepts);
            localStorage.setItem('poswords', JSON.stringify(res.poswords));
            localStorage.setItem('negwords', JSON.stringify(res.negwords));
            localStorage.setItem('contextprev', res.contextprev);
            localStorage.setItem('contextmiddle', res.contextmiddle);
            localStorage.setItem('contextnext', res.contextnext);
            localStorage.setItem('wordssplitnum', res.wordssplitnum);
            localStorage.setItem('punctuation', res.punctuation);
            localStorage.setItem('stopwords', res.stopwords);
            localStorage.setItem('lowercase', res.lowercase);
            localStorage.setItem('stemming', res.stemming);
            localStorage.setItem('documentarea', res.documentarea);
            this.router.navigate(['../upload-content'], { relativeTo: this.route, queryParamsHandling: 'preserve' });
        });
    }
    downloadUserProfileAdmin(userId, profileId, profileName) {
        this.manageProfilesService.downloadUserProfileAdmin(userId, profileId)
            .subscribe(res => {
            saveFile(res, profileName.replace(/ /g, '_') + '.oamp');
        });
    }
    onStatusChange(userId, profileId, status) {
        this.manageProfilesService.updateProfileStatus(userId, profileId, status)
            .subscribe();
    }
    loadSavedProfile(id, name) {
        this.manageProfilesService.loadSavedProfile(id)
            .subscribe(res => {
            console.log(res);
            // clear localstorage values
            this.clearLocalStorage();
            // store to client all profile data
            localStorage.setItem('profilename', name);
            localStorage.setItem('profileid', id);
            localStorage.setItem('docname', res.docname);
            localStorage.setItem('docsnumber', res.docsnumber);
            localStorage.setItem('concepts', res.concepts);
            localStorage.setItem('poswords', JSON.stringify(res.poswords));
            localStorage.setItem('negwords', JSON.stringify(res.negwords));
            localStorage.setItem('contextprev', res.contextprev);
            localStorage.setItem('contextmiddle', res.contextmiddle);
            localStorage.setItem('contextnext', res.contextnext);
            localStorage.setItem('wordssplitnum', res.wordssplitnum);
            localStorage.setItem('punctuation', res.punctuation);
            localStorage.setItem('stopwords', res.stopwords);
            localStorage.setItem('lowercase', res.lowercase);
            localStorage.setItem('stemming', res.stemming);
            localStorage.setItem('documentarea', res.documentarea);
            this.router.navigate(['../upload-content'], { relativeTo: this.route, queryParamsHandling: 'preserve' });
        });
    }
    downloadProfile(profileId, profileName) {
        this.manageProfilesService.downloadProfile(profileId)
            .subscribe(res => {
            saveFile(res, profileName.replace(/ /g, '_') + '.oamp');
        });
    }
    deleteProfilePrompt(index) {
        UIkit.modal.confirm('<span class="uk-text-bold uk-text-danger">' +
            'Are you sure you want to delete this profile? This action cannot be undone!</span>', { escClose: true }).then(() => {
            this.manageProfilesService.deleteProfile(this.userSavedProfiles[index].id)
                .subscribe(() => this.userSavedProfiles.splice(index, 1));
        });
    }
    createNewProfile() {
        // clear localstorage values
        this.clearLocalStorage();
        this.manageProfilesService.createNewProfile()
            .subscribe(() => this.router.navigate(['../upload-content'], { relativeTo: this.route, queryParamsHandling: 'preserve' }));
    }
    fileChangeUpload(event) {
        // clear localstorage values
        this.clearLocalStorage();
        const fileList = event.target.files;
        if (fileList && fileList.length === 1) {
            const file = fileList[0];
            // get new profile data
            this.manageProfilesService.uploadFile(file)
                .subscribe(res => {
                console.log(res);
                localStorage.setItem('concepts', res.concepts);
                localStorage.setItem('poswords', JSON.stringify(res.poswords));
                localStorage.setItem('negwords', JSON.stringify(res.negwords));
                localStorage.setItem('contextprev', res.contextprev);
                localStorage.setItem('contextmiddle', res.contextmiddle);
                localStorage.setItem('contextnext', res.contextnext);
                localStorage.setItem('wordssplitnum', res.wordssplitnum);
                localStorage.setItem('punctuation', res.punctuation);
                localStorage.setItem('stopwords', res.stopwords);
                localStorage.setItem('lowercase', res.lowercase);
                localStorage.setItem('stemming', res.stemming);
                localStorage.setItem('documentarea', res.documentarea);
                this.router.navigate(['../upload-content'], { relativeTo: this.route, queryParamsHandling: 'preserve' });
            });
        }
    }
    notifyProfile(profile) {
        UIkit.modal.confirm('<span class="uk-text-bold">' +
            'A notification will be sent to the OpenAIRE Mining experts, ' +
            'that your profile is in its final version!</br></br>' +
            'Are you sure you want to proceed?</span>', { escClose: true }).then(() => {
            this.pending = true;
            this.manageProfilesService.notifyProfile(this.communityId, profile.id)
                .subscribe(res => {
                profile.notified = 1;
                this.pending = false;
            });
        });
    }
    loadExampleProfile(name) {
        // clear localstorage values
        this.clearLocalStorage();
        // get new profile data
        this.manageProfilesService.loadExampleProfile(name)
            .subscribe(res => {
            console.log(res);
            localStorage.setItem('concepts', res.concepts);
            localStorage.setItem('docname', res.docname);
            localStorage.setItem('docsnumber', res.docsnumber);
            localStorage.setItem('poswords', JSON.stringify(res.poswords));
            localStorage.setItem('negwords', JSON.stringify(res.negwords));
            localStorage.setItem('contextprev', res.contextprev);
            localStorage.setItem('contextmiddle', res.contextmiddle);
            localStorage.setItem('contextnext', res.contextnext);
            localStorage.setItem('wordssplitnum', res.wordssplitnum);
            localStorage.setItem('punctuation', res.punctuation);
            localStorage.setItem('stopwords', res.stopwords);
            localStorage.setItem('lowercase', res.lowercase);
            localStorage.setItem('stemming', res.stemming);
            localStorage.setItem('documentarea', res.documentarea);
            this.router.navigate(['../upload-content'], { relativeTo: this.route, queryParamsHandling: 'preserve' });
        });
    }
};
ManageprofilesComponent = __decorate([
    Component({
        selector: 'app-manageprofiles',
        template: "<app-stepsnvabar></app-stepsnvabar>\n<div *ngIf=\"isCommunityManager\" class=\"uk-section uk-section-default\">\n  <div class=\"uk-container uk-container-expand\">\n    <h4>Administrate all profiles <span class=\"cm-tooltip\" uk-icon=\"icon: info\" title=\"Each <b>mining profile</b> consists of the data and the rules used to define a <b>mining procedure</b>.<br>Click the profile to <b>edit</b>.\" uk-tooltip=\"pos: right\"></span></h4>\n    <div class=\"uk-overflow-auto\">\n      <table class=\"uk-table uk-table-hover uk-table-middle uk-table-divider\">\n        <thead>\n        <tr>\n          <th class=\"uk-table-small cm-text-muted\">Community</th>\n          <th class=\"uk-table-expand cm-text-muted\">Profile</th>\n          <th class=\"uk-table-small cm-text-muted\">Modified</th>\n          <th class=\"uk-width-small cm-text-muted\">Status</th>\n          <th class=\"uk-table-shrink\"></th>\n          <!--<th class=\"uk-table-shrink uk-text-nowrap\">Matches</th>-->\n        </tr>\n        </thead>\n        <tfoot>\n        </tfoot>\n        <tbody>\n        <tr *ngFor=\"let profile of allUsersProfiles | paginate: allProfiles; let i = index\">\n          <td class=\"uk-text-nowrap\">{{profile.user}}</td>\n          <td class=\"uk-table-link\">\n            <a class=\"uk-link-reset\" (click)=\"loadUserProfileAdmin(profile.userId, profile.profileId, profile.profile)\">{{profile.profile}}</a>\n          </td>\n          <td class=\"cm-text-muted uk-text-nowrap\">{{profile.datecreated}}</td>\n          <td class=\"uk-text-nowrap uk-text-warning\">\n            <select [(ngModel)]=\"profile.status\" (ngModelChange)=\"onStatusChange(profile.userId, profile.profileId, $event)\">\n              <option *ngFor=\"let status of statusValues\" [ngValue]=\"status\">{{status}}</option>\n            </select>\n          </td>\n          <td class=\"download\">\n            <a class=\"uk-icon-link uk-icon\" uk-icon=\"icon: download\" contenteditable=\"false\" (click)=\"downloadUserProfileAdmin(profile.userId, profile.profileId, profile.profile)\"></a>\n          </td>\n          <!--<td class=\"uk-text-nowrap\">{{profile.matches}}</td>-->\n        </tr>\n        </tbody>\n      </table>\n      <pagination-template *ngIf=\"allUsersProfiles.length\" #p=\"paginationApi\"\n                           [id]=\"allProfiles.id\"\n                           (pageChange)=\"allProfiles.currentPage = $event\">\n        <ul class=\"uk-pagination uk-flex-center\" uk-margin>\n          <li [class.uk-disabled]=\"p.isFirstPage()\"><a (click)=\"p.previous()\"><span uk-pagination-previous></span></a></li>\n          <li *ngFor=\"let page of p.pages\" [class.uk-active]=\"p.getCurrent() === page.value\">\n            <a (click)=\"p.setCurrent(page.value)\" *ngIf=\"p.getCurrent() !== page.value\">\n              <span>{{ page.label }}</span>\n            </a>\n            <span *ngIf=\"p.getCurrent() === page.value\">{{ page.label }}</span>\n          </li>\n          <li [class.uk-disabled]=\"p.isLastPage()\"><a (click)=\"p.next()\"><span uk-pagination-next></span></a></li>\n        </ul>\n      </pagination-template>\n    </div>\n  </div>\n</div>\n\n<div class=\"uk-section uk-section-default\">\n  <div class=\"uk-container uk-container-expand\">\n    <h4>My mining profiles <span class=\"cm-tooltip\" uk-icon=\"icon: info\" title=\"Each <b>mining profile</b> consists of the data and the rules used to define a <b>mining procedure</b>.<br>Click the profile to <b>edit</b>.\" uk-tooltip=\"pos: right\"></span></h4>\n    <!--<div uk-grid>-->\n      <!--<div class=\"uk-width-expand@m\">-->\n        <div class=\"uk-overflow-auto\">\n          <table class=\"uk-table uk-table-hover uk-table-middle uk-table-divider\">\n            <thead>\n            <tr>\n              <!--<th class=\"uk-table-shrink\"></th>-->\n              <th class=\"uk-table-expand cm-text-muted\">Profile</th>\n              <th class=\"uk-table-small cm-text-muted\">Modified</th>\n              <th class=\"uk-table-small cm-text-muted\">Notified <span class=\"cm-tooltip\" uk-icon=\"icon: info\" title=\"When your profile is in its final version, notify the OpenAIRE Mining experts to process it\" uk-tooltip=\"pos: right\"></span></th>\n              <th class=\"uk-width-small cm-text-muted\">Status</th>\n              <!--<th class=\"uk-table-shrink uk-text-nowrap\">Matches</th>-->\n              <th></th>\n            </tr>\n            </thead>\n            <tfoot>\n            </tfoot>\n            <tbody>\n            <tr *ngIf=\"!userSavedProfiles.length\">\n              <!-- <td class=\"cm-table-number\"></td> -->\n              <td colspan=\"5\">\n                <div class=\"uk-text-center uk-padding uk-padding-remove-bottom\">\n                  <h3>Not created your profile yet?</h3>\n                  <p class=\"uk-text-lead\">\n                    Try to play with an example profile below!\n                  </p>\n                  <div class=\"uk-heading-line uk-text-center uk-margin-auto cm-margin-medium\" style=\"width: 335px;\"><span>or</span></div>\n                  <a class=\"test-upload uk-button cm-button-primary uk-text-center cm-margin\" (click)=\"createNewProfile()\">\n                    <span class=\"uk-text-middle\">Create a new mining profile</span>\n                  </a>\n                </div>\n              </td>\n            </tr>\n            <tr *ngFor=\"let profile of userSavedProfiles| paginate: userProfiles; let i = index\" >\n              <!--<td class=\"download\">-->\n                <!--<a class=\"uk-icon-link uk-icon\" uk-icon=\"icon: download\" contenteditable=\"false\" (click)=\"downloadProfile(profile.id, profile.name)\"></a>-->\n              <!--</td>-->\n              <td class=\"uk-table-link\">\n                <a class=\"uk-link-reset\" (click)=\"loadSavedProfile(profile.id, profile.name)\">{{profile.name}}</a>\n              </td>\n              <td class=\"cm-text-muted uk-text-nowrap\">{{profile.datecreated}}</td>\n              <td class=\"cm-text-muted uk-text-nowrap\">\n                <button *ngIf=\"!profile.notified && !pending\" class=\"uk-button uk-button-secondary uk-button-small uk-text-center cm-margin\" (click)=\"notifyProfile(profile)\">Notify</button>\n                <button *ngIf=\"pending\" class=\"uk-button uk-button-secondary uk-button-small uk-text-center cm-margin\" disabled>Notifying... <span uk-spinner=\"ratio: 0.8\"></span></button>\n                <span *ngIf=\"profile.notified \" class=\"uk-label uk-label-success\">Notified</span>\n              </td>\n              <td class=\"uk-text-nowrap uk-text-warning\">{{profile.status}}</td>\n              <!--<td class=\"uk-text-nowrap\">{{profile.matches}}</td>-->\n              <td class=\"delete\">\n                <a class=\"uk-icon-link uk-icon\" uk-icon=\"icon: trash\" contenteditable=\"false\" (click)=\"deleteProfilePrompt(i)\"></a>\n              </td>\n            </tr>\n            </tbody>\n          </table>\n          <pagination-template *ngIf=\"userSavedProfiles.length\" #u=\"paginationApi\"\n                               [id]=\"userProfiles.id\"\n                               (pageChange)=\"userProfiles.currentPage = $event\">\n            <ul class=\"uk-pagination uk-flex-center\" uk-margin>\n              <li [class.uk-disabled]=\"u.isFirstPage()\"><a (click)=\"u.previous()\"><span uk-pagination-previous></span></a></li>\n              <li *ngFor=\"let page of u.pages\" [class.uk-active]=\"u.getCurrent() === page.value\">\n                <a (click)=\"u.setCurrent(page.value)\" *ngIf=\"u.getCurrent() !== page.value\">\n                  <span>{{ page.label }}</span>\n                </a>\n                <span *ngIf=\"u.getCurrent() === page.value\">{{ page.label }}</span>\n              </li>\n              <li [class.uk-disabled]=\"u.isLastPage()\"><a (click)=\"u.next()\"><span uk-pagination-next></span></a></li>\n            </ul>\n          </pagination-template>\n        </div>\n      <!--</div>-->\n      <!--<div class=\"uk-width-1-3@m\">-->\n        <!--<a class=\"test-upload uk-button cm-button-primary uk-width-1-1 uk-text-center uk-margin-small-bottom\" (click)=\"createNewProfile()\">-->\n          <!--<span class=\"uk-text-middle\">Create a new mining profile</span>-->\n        <!--</a>-->\n        <!--&lt;!&ndash;<div class=\"test-upload uk-button uk-button-link uk-width-1-1 uk-text-center uk-margin-small-top\">&ndash;&gt;-->\n          <!--&lt;!&ndash;<div uk-form-custom>&ndash;&gt;-->\n            <!--&lt;!&ndash;<form id=\"profile-input-form\" method=\"post\" enctype=\"multipart/form-data\" accept-charset=\"UTF-8\">&ndash;&gt;-->\n              <!--&lt;!&ndash;<input type=\"file\" name=\"upload\" id=\"profile-file-input\" class=\"inputfile\" (change)=\"fileChangeUpload($event)\" accept=\".oamp\">&ndash;&gt;-->\n            <!--&lt;!&ndash;</form>&ndash;&gt;-->\n            <!--&lt;!&ndash;<span class=\"uk-text-middle\">UPLOAD an .oamp profile file</span>&ndash;&gt;-->\n          <!--&lt;!&ndash;</div>&ndash;&gt;-->\n        <!--&lt;!&ndash;</div>&ndash;&gt;-->\n      <!--</div>-->\n    <!--</div>-->\n    <div *ngIf=\"userSavedProfiles.length > 0\" class=\"uk-container-small\">\n      <a class=\"test-upload uk-button cm-button-primary uk-text-center cm-margin\" (click)=\"createNewProfile()\">\n        <span class=\"uk-text-middle\">Create a new mining profile</span>\n      </a>\n    </div>\n  </div>\n</div>\n<h4>Start with an example profile</h4>\n<div class=\"uk-section uk-section-secondary cm-section-examples\">\n  <div class=\"uk-container uk-container-small\">\n    <div uk-slider=\"autoplay: true\">\n      <div class=\"uk-position-relative\">\n        <div class=\"uk-slider-container uk-light\">\n          <ul class=\"uk-slider-items cm-child-width-examples-cards uk-grid\">\n            <li *ngFor=\"let profile of exampleProfiles\">\n              <a (click)=\"loadExampleProfile(profile.name)\">\n                <div class=\"uk-card uk-card-default uk-card-hover uk-card-body uk-text-center uk-margin-medium-top uk-margin-medium-bottom\">\n                  <h3 class=\"uk-card-title examples-text uk-text-bold\">{{profile.name | uppercase}}</h3>\n                  <h4 class=\"uk-card-title examples-text uk-margin-remove-bottom\">{{profile.contents}}</h4>\n                  <p class=\"uk-text-small uk-margin-remove-top\">concepts</p>\n                  <h4 class=\"uk-card-title examples-text uk-margin-remove-bottom\">{{profile.documents}}</h4>\n                  <p class=\"uk-text-small uk-margin-remove-top\">documents</p>\n                </div>\n              </a>\n            </li>\n          </ul>\n        </div>\n        <div class=\"uk-hidden@s\">\n          <a class=\"uk-position-center-left uk-position-small\" href=\"#\" uk-slidenav-previous uk-slider-item=\"previous\"></a>\n          <a class=\"uk-position-center-right uk-position-small\" href=\"#\" uk-slidenav-next uk-slider-item=\"next\"></a>\n        </div>\n        <div class=\"uk-visible@s\">\n          <a class=\"uk-position-center-left-out uk-position-small\" href=\"#\" uk-slidenav-previous uk-slider-item=\"previous\"></a>\n          <a class=\"uk-position-center-right-out uk-position-small\" href=\"#\" uk-slidenav-next uk-slider-item=\"next\"></a>\n        </div>\n      </div>\n      <ul class=\"uk-slider-nav uk-dotnav uk-flex-center uk-margin\"></ul>\n    </div>\n  </div>\n</div>\n"
    }),
    __metadata("design:paramtypes", [ManageprofilesService, ActivatedRoute, Router])
], ManageprofilesComponent);

let ManageprofilesModule = class ManageprofilesModule {
};
ManageprofilesModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            FormsModule,
            NgxPaginationModule,
            StepsnavbarModule
        ],
        exports: [
            ManageprofilesComponent
        ],
        providers: [
            ManageprofilesService
        ],
        declarations: [ManageprofilesComponent]
    })
], ManageprofilesModule);

let SaveprofileService = class SaveprofileService {
    constructor(http) {
        this.http = http;
        this.util = new Util();
        this.userId = '';
        this.backendServerAddress = '';
        this.saveProfileUrl = '/saveprofile';
        this.userId = this.util.getUserId();
        this.backendServerAddress = this.util.getBackendServerAddress();
    }
    saveProfile(name, id, docName, dosNumber) {
        return this.http.post(this.backendServerAddress + this.saveProfileUrl, { user: this.userId, name: name, id: id, docname: docName, docsnumber: dosNumber })
            .pipe(catchError(this.util.handleError));
    }
};
SaveprofileService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [HttpClient])
], SaveprofileService);

let SaveprofileComponent = class SaveprofileComponent {
    constructor(saveprofileService, route, router) {
        this.saveprofileService = saveprofileService;
        this.route = route;
        this.router = router;
        this.profileId = '';
        this.profileName = 'New profile name';
        this.docnName = '';
        this.docsNumber = 0;
    }
    ngOnInit() {
        if (localStorage.getItem('profileid') && localStorage.getItem('profileid') !== 'undefined') {
            this.profileId = localStorage.getItem('profileid');
        }
        // if (localStorage.getItem('profilename') && localStorage.getItem('profilename') !== 'undefined') {
        //   this.profileName = localStorage.getItem('profilename');
        // }
        if (localStorage.getItem('docname') && localStorage.getItem('docname') !== 'undefined') {
            this.docnName = localStorage.getItem('docname');
        }
        if (localStorage.getItem('docsnumber') && localStorage.getItem('docsnumber') !== 'undefined') {
            this.docsNumber = Number.parseInt(localStorage.getItem('docsnumber'));
        }
    }
    saveCurrentProfile() {
        this.saveprofileService.saveProfile(this.profileName, this.profileId, this.docnName, this.docsNumber)
            .subscribe(() => this.router.navigate(['../manage-profiles'], { relativeTo: this.route, queryParamsHandling: 'preserve' }));
    }
    saveNewProfile() {
        if (this.profileName === '') {
            UIkit.notification({
                message: 'You have to provide a name to your new profile',
                status: 'danger',
                pos: 'top-center',
                timeout: 4000
            });
            return;
        }
        else {
            this.saveprofileService.saveProfile(this.profileName, '', this.docnName, this.docsNumber)
                .subscribe(() => this.router.navigate(['../manage-profiles'], { relativeTo: this.route, queryParamsHandling: 'preserve' }));
        }
    }
};
SaveprofileComponent = __decorate([
    Component({
        selector: 'app-saveprofile',
        template: "<app-stepsnvabar></app-stepsnvabar>\n<div class=\"uk-section uk-section-default\"  style=\"padding-top: 20px;\">\n  <div class=\"uk-container uk-width-1-3 uk-align-left\">\n    <button *ngIf=\"profileId\" class=\"uk-button cm-button-primary uk-width-1-1 uk-button-medium uk-text-center\" (click)=\"saveCurrentProfile()\">Save changes</button>\n    <div *ngIf=\"profileId\" class=\"uk-heading-line uk-text-center uk-margin-medium\"><span>or</span></div>\n    <!--<label for=\"profile-name\" [ngClass]=\"{'uk-text-danger':!profileName}\">New profile's name:</label>-->\n    <input [(ngModel)]=\"profileName\" class=\"uk-input\" id=\"profile-name\" type=\"text\" placeholder=\"Profile name\" autofocus>\n    <span *ngIf=\"!profileName\" class=\"uk-text-danger\">Profile name cannot be empty!</span>\n    <button *ngIf=\"profileId\" class=\"uk-button cm-button-primary cm-margin-medium-top uk-width-1-1 uk-button-medium uk-text-center\" [disabled]=\"!profileName\" (click)=\"saveNewProfile()\">Save as new profile</button>\n    <button *ngIf=\"!profileId\" class=\"uk-button cm-button-primary cm-margin-medium-top uk-width-1-1 uk-button-medium uk-text-center\" [disabled]=\"!profileName\" (click)=\"saveNewProfile()\">Save profile</button>\n  </div>\n</div>\n",
        styles: [""]
    }),
    __metadata("design:paramtypes", [SaveprofileService, ActivatedRoute, Router])
], SaveprofileComponent);

let SaveprofileModule = class SaveprofileModule {
};
SaveprofileModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            FormsModule,
            StepsnavbarModule
        ],
        exports: [
            SaveprofileComponent
        ],
        providers: [
            SaveprofileService
        ],
        declarations: [SaveprofileComponent]
    })
], SaveprofileModule);

class Content {
}

let ContentsService = class ContentsService {
    constructor(http) {
        this.http = http;
        this.util = new Util();
        this.userId = '';
        this.backendServerAddress = '';
        this.concepts = '';
        this.getContentUrl = '/alreadyconcept';
        this.uploadContentFileUrl = '/uploadcontentfile';
        this.updateContentUrl = '/updateconcept';
        this.userId = this.util.getUserId();
        this.backendServerAddress = this.util.getBackendServerAddress();
    }
    getContent() {
        this.concepts = localStorage.getItem('concepts');
        return this.http.get(this.backendServerAddress + this.getContentUrl + `?user=${this.userId}&concepts=${this.concepts}`)
            .pipe(map((data) => this.contentsJsonToArray(data['data'])))
            .pipe(catchError(this.util.handleError));
    }
    contentsJsonToArray(json) {
        const contentArray = [];
        for (const key in json) {
            if (key) {
                const content = new Content();
                content.keyword = key;
                content.context = json[key];
                contentArray.push(content);
            }
        }
        return contentArray;
    }
    uploadFile(file) {
        const formData = new FormData();
        formData.append('upload', file, file.name);
        formData.append('user', this.userId);
        const params = new HttpParams();
        const options = {
            headers: new HttpHeaders().set('Accept', 'application/json').delete('Content-Type'),
            params: params,
            reportProgress: true
        };
        return this.http.post(this.backendServerAddress + this.uploadContentFileUrl, formData, options)
            .pipe(map((data) => this.contentsJsonToArray(data['data'])))
            .pipe(catchError(this.util.handleError));
    }
    updateContent(content) {
        // transform data to json string
        const hashmap = {};
        content.forEach(function (element) {
            hashmap[element.keyword] = element.context;
        });
        return this.http.post(this.backendServerAddress + this.updateContentUrl, { user: this.userId, concepts: JSON.stringify(hashmap) })
            .pipe(map((data) => data['concepts']))
            .pipe(catchError(this.util.handleError));
    }
};
ContentsService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [HttpClient])
], ContentsService);

let ContentComponent = class ContentComponent {
    constructor(contentsService, route, router) {
        this.contentsService = contentsService;
        this.route = route;
        this.router = router;
        this.contentArray = [];
        this.selectedRow = -1;
        this.selectedCollumn = 0;
        this.results = '';
    }
    ngOnInit() {
        this.getContent();
        this.router.events.subscribe((evt) => {
            if (!(evt instanceof NavigationEnd)) {
                return;
            }
            window.scrollTo(0, 0);
        });
    }
    getContent() {
        this.contentsService.getContent()
            .subscribe(contents => {
            this.contentArray = contents;
            if (!this.contentArray.length) {
                this.addRow();
            }
        });
    }
    selectRowColumn(row, column) {
        this.selectedRow = row;
        this.selectedCollumn = column;
    }
    unselectRow() {
        this.selectedRow = -1;
    }
    addRow() {
        const content = new Content();
        content.keyword = '';
        content.context = '';
        this.contentArray.push(content);
        setTimeout(() => {
            this.focusOnNewInputs.toArray()[this.contentArray.length - 1].nativeElement.focus();
        }, 100);
    }
    isAnyContent() {
        let checked = false;
        this.contentArray.forEach(function (element) {
            if (element.keyword !== '') {
                checked = true;
                return;
            }
        });
        return checked;
    }
    deleteFieldValue(index) {
        UIkit.modal.confirm('<span class="uk-text-bold">' +
            'Are you sure you want to delete this content row?</span>', { escClose: true }).then(() => {
            this.contentArray.splice(index, 1);
            if (!this.contentArray.length) {
                this.addRow();
            }
        });
    }
    deleteAllFields() {
        UIkit.modal.confirm('<span class="uk-text-bold">' +
            'Are you sure you want to delete all your content?</span>', { escClose: true }).then(() => {
            this.contentArray.length = 0;
            this.addRow();
        });
    }
    onFilesChange(file) {
        if (file !== null && file !== undefined) {
            console.log(file);
            const ext = file.name.split('.')[file.name.split('.').length - 1];
            const allowedExtensions = ['tsv', 'txt'];
            if (allowedExtensions.lastIndexOf(ext) !== -1 && file.size <= 51200) {
                this.contentsService.uploadFile(file)
                    .subscribe(contents => {
                    if (contents.length !== 0) {
                        this.contentArray = contents;
                        localStorage.setItem('concepts', contents.length.toString());
                    }
                });
            }
            else {
                this.onFileInvalid(file);
            }
        }
    }
    onFileInvalid(file) {
        if (file !== null && file !== undefined) {
            console.log('ERROR', file);
        }
    }
    saveAndContinue() {
        this.contentsService.updateContent(this.contentArray)
            .subscribe(value => {
            localStorage.setItem('concepts', value);
            this.router.navigate(['../configure-profile'], { relativeTo: this.route, queryParamsHandling: 'preserve' });
        });
    }
    promptToLeave(nextUrl) {
        console.log(nextUrl);
        if (nextUrl.indexOf('upload-content') >= 0 || nextUrl.indexOf('configure-profile') >= 0 || nextUrl.indexOf('save-profile') >= 0) {
            return true;
        }
        else {
            return UIkit.modal.confirm('<span class="uk-text-bold">' +
                'Your changes have not been saved to your Profile!<br>Are you sure you want to leave?</span>', { escClose: true }).then(() => {
                return true;
            }, () => false);
        }
    }
};
__decorate([
    ViewChildren('focusOnNew'),
    __metadata("design:type", Object)
], ContentComponent.prototype, "focusOnNewInputs", void 0);
ContentComponent = __decorate([
    Component({
        selector: 'app-contents',
        template: "<app-stepsnvabar></app-stepsnvabar>\n<div class=\"uk-section uk-section-default\" style=\"padding-top: 20px;\">\n  <div class=\"uk-container uk-container-expand\">\n    <div class=\"uk-grid-collapse uk-child-width-expand uk-text-middle\" uk-grid>\n      <p class=\"uk-margin-small-left\">Use the table or the upload form to add your concepts <span class=\"cm-tooltip\" uk-icon=\"icon: info\" title=\"Provide <b>two columns</b> of data. The first column is a list of keywords that must be found in a publications\u2019 fulltext. Such <b>keyword</b> may be a concept name, the name of an initiative of a community etc.<br>The second column provide a context. The <b>context</b> may be an acknowledgement statement or other phrase that is expected to be found when the concept in the first column is acknowledged. Both columns accept a valid <b>Regular expression</b>.\" uk-tooltip=\"pos: right\"></span></p>\n      <div class=\"uk-text-right\">\n        <button class=\"uk-button cm-button-primary\" [disabled]=\"!isAnyContent()\" (click)=\"saveAndContinue()\">Continue</button>\n      </div>\n    </div>\n    <table id=\"data-table\" class=\"uk-table uk-table-hover cm-table\">\n      <thead>\n      <tr>\n        <!-- <th class=\"uk-table-shrink cm-table-number\">#</th> -->\n        <th class=\"uk-width-small cm-text-muted\">Keyword</th>\n        <th class=\"uk-table-expand cm-text-muted\">Context <span class=\"uk-text-capitalize\">(Optional)</span></th>\n        <th class=\"uk-table-shrink\" style=\"width: 100px;\">\n          <a class=\"uk-icon-link\" (click)=\"deleteAllFields()\">\n            <span contenteditable=\"false\" class=\"uk-icon\" uk-icon=\"icon: trash\"></span>\n            <span class=\"uk-text-middle\">Delete All</span>\n          </a>\n        </th>\n      </tr>\n      </thead>\n      <tbody>\n      <tr *ngFor=\"let field of contentArray; let i = index\" [ngClass]=\"{'editing':i===selectedRow}\">\n        <td class=\"keyword\" [ngClass]=\"{'editing':i===selectedRow && 0===selectedCollumn}\">\n          <input #focusOnNew [(ngModel)]=\"field.keyword\" class=\"form-control\" type=\"text\" style=\"width:100%\" (focus)=\"selectRowColumn(i, 0)\" (focusout)=\"unselectRow()\"/>\n        </td>\n        <td class=\"context\" [ngClass]=\"{'editing':i===selectedRow && 1===selectedCollumn}\">\n        <textarea autosize [(ngModel)]=\"field.context\" class=\"form-control uk-textarea\" data-min-rows='3' type=\"text\" (focus)=\"selectRowColumn(i, 1)\" (focusout)=\"unselectRow()\">\n        </textarea>\n        </td>\n        <td class=\"delete\">\n          <a class=\"uk-icon-link uk-icon\" uk-icon=\"icon: trash\" contenteditable=\"false\" (click)=\"deleteFieldValue(i)\"></a>\n        </td>\n      </tr>\n      </tbody>\n      <tfoot>\n      <tr>\n        <!-- <td class=\"cm-table-number\"></td> -->\n        <td colspan=\"3\" class=\"cm-table-footer\">\n          <button (click)=\"addRow()\" [disabled]=\"!isAnyContent()\" id=\"add-row-below\" class=\"uk-button uk-button-default uk-width-1-1 uk-text-center\">\n            <span class=\"uk-text-middle\"><span uk-icon=\"icon: plus-circle\"></span> Add row</span>\n          </button>\n        </td>\n      </tr>\n      <tr *ngIf=\"contentArray.length<2 && !isAnyContent()\">\n        <td colspan=\"3\" class=\"cm-table-footer\" style=\"padding: 70px 80px 50px;\">\n          <div appDropFileUpload (filesChange)=\"onFilesChange($event)\" (filesInvalid)=\"onFileInvalid($event)\" [allowedExtensions]=\"['tsv', 'txt']\" [maxFileSize]=\"51200\" class=\"uk-placeholder cm-file-drop-area cm-coloured-text\">\n            <div class=\"uk-flex uk-flex-middle uk-grid-collapse uk-child-width-expand@s\" uk-grid>\n              <div>\n                <div class=\"cm-coloured-text\">\n                  <span uk-icon=\"icon: cloud-upload\"></span>\n                  <span class=\"uk-text-middle\"> Drop file with content here to fill the table!</span>\n                </div>\n                <div>\n                  <span class=\"cm-label\">TSV</span>\n                  <span class=\"uk-text uk-text-small cm-coloured-text-meta\">file type, maximum 50kB</span>\n                </div>\n              </div>\n              <div uk-form-custom>\n                <input type=\"file\" name=\"upload\" id=\"codes-file-input\" class=\"inputfile\" (change)=\"onFilesChange($event.srcElement.files[0])\" />\n                <button class=\"uk-button uk-button-default cm-main-button\" type=\"button\" tabindex=\"-1\">Choose file</button>\n              </div>\n            </div>\n          </div>\n          <progress id=\"js-progressbar\" class=\"uk-progress\" value=\"0\" max=\"100\" hidden></progress>\n        </td>\n      </tr>\n      </tfoot>\n    </table>\n  </div>\n</div>\n",
        styles: [""]
    }),
    __metadata("design:paramtypes", [ContentsService, ActivatedRoute, Router])
], ContentComponent);

let FileUploadDirective = class FileUploadDirective {
    constructor() {
        this.allowedExtensions = [];
        this.maxFileSize = 104857600;
        this.filesChange = new EventEmitter();
        this.filesInvalid = new EventEmitter();
        this.background = 'uk-placeholder cm-file-drop-area cm-coloured-text';
    }
    onDragOver(evt) {
        evt.preventDefault();
        evt.stopPropagation();
        this.background = 'uk-placeholder cm-file-drop-area cm-coloured-text uk-dragover';
    }
    onDragLeave(evt) {
        evt.preventDefault();
        evt.stopPropagation();
        this.background = 'uk-placeholder cm-file-drop-area cm-coloured-text';
    }
    onDrop(evt) {
        evt.preventDefault();
        evt.stopPropagation();
        this.background = 'uk-placeholder cm-file-drop-area cm-coloured-text';
        const files = evt.dataTransfer.files;
        let valid_file = null;
        let invalid_file = null;
        if (files.length === 1) {
            const file = files[0];
            const ext = file.name.split('.')[file.name.split('.').length - 1];
            if (this.allowedExtensions.lastIndexOf(ext) !== -1 && file.size <= this.maxFileSize) {
                valid_file = file;
            }
            else {
                invalid_file = file;
            }
            this.filesChange.emit(valid_file);
            this.filesInvalid.emit(invalid_file);
        }
    }
};
__decorate([
    Input(),
    __metadata("design:type", Array)
], FileUploadDirective.prototype, "allowedExtensions", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], FileUploadDirective.prototype, "maxFileSize", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], FileUploadDirective.prototype, "filesChange", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], FileUploadDirective.prototype, "filesInvalid", void 0);
__decorate([
    HostBinding('class'),
    __metadata("design:type", Object)
], FileUploadDirective.prototype, "background", void 0);
__decorate([
    HostListener('dragover', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], FileUploadDirective.prototype, "onDragOver", null);
__decorate([
    HostListener('dragleave', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], FileUploadDirective.prototype, "onDragLeave", null);
__decorate([
    HostListener('drop', ['$event']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], FileUploadDirective.prototype, "onDrop", null);
FileUploadDirective = __decorate([
    Directive({
        selector: '[appDropFileUpload]'
    }),
    __metadata("design:paramtypes", [])
], FileUploadDirective);

let AutosizeDirective = class AutosizeDirective {
    constructor(element) {
        this.element = element;
    }
    onInput() {
        this.resize();
    }
    ngAfterContentChecked() {
        this.resize();
    }
    resize() {
        const style = this.element.nativeElement.style;
        style.overflow = 'hidden';
        style.height = 'auto';
        const height = this.element.nativeElement.scrollHeight;
        style.height = `${height}px`;
    }
};
__decorate([
    HostListener('input'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], AutosizeDirective.prototype, "onInput", null);
AutosizeDirective = __decorate([
    Directive({
        selector: 'textarea[autosize]'
    }),
    __metadata("design:paramtypes", [ElementRef])
], AutosizeDirective);

let ContentModule = class ContentModule {
};
ContentModule = __decorate([
    NgModule({
        exports: [
            ContentComponent
        ],
        providers: [
            ContentsService
        ],
        imports: [
            CommonModule,
            FormsModule,
            StepsnavbarModule
        ],
        declarations: [
            ContentComponent,
            FileUploadDirective,
            AutosizeDirective
        ]
    })
], ContentModule);

let InteractiveMiningModule = class InteractiveMiningModule {
};
InteractiveMiningModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            ManageprofilesModule,
            ContentModule,
            ConfigurationModule,
            SaveprofileModule,
            HttpClientModule
        ]
    })
], InteractiveMiningModule);

let SaveProfileGuard = class SaveProfileGuard {
    canDeactivate(component, currentRoute, currentState, nextState) {
        return component.promptToLeave(nextState.toString());
    }
};
SaveProfileGuard = __decorate([
    Injectable()
], SaveProfileGuard);
let UploadContentGuard = class UploadContentGuard {
    canDeactivate(component, currentRoute, currentState, nextState) {
        return component.promptToLeave(nextState.toString());
    }
};
UploadContentGuard = __decorate([
    Injectable()
], UploadContentGuard);

const interactiveMiningRoutes = [
    { path: '', redirectTo: '/mining/manage-profiles', pathMatch: 'full' },
    {
        path: '',
        // component: InteractiveMiningComponent,
        children: [
            { path: 'manage-profiles', component: ManageprofilesComponent },
            { path: 'upload-content',
                component: ContentComponent,
                canDeactivate: [UploadContentGuard]
            },
            { path: 'configure-profile',
                component: ConfigurationComponent,
                canDeactivate: [SaveProfileGuard]
            },
            { path: 'save-profile', component: SaveprofileComponent }
        ]
    }
];
let InteractiveMiningRoutingModule = class InteractiveMiningRoutingModule {
};
InteractiveMiningRoutingModule = __decorate([
    NgModule({
        imports: [
            RouterModule.forChild(interactiveMiningRoutes)
        ],
        exports: [
            RouterModule
        ],
        providers: [
            UploadContentGuard,
            SaveProfileGuard
        ]
    })
], InteractiveMiningRoutingModule);

/**
 * Generated bundle index. Do not edit.
 */

export { InteractiveMiningModule, InteractiveMiningRoutingModule, ManageprofilesModule as ɵa, StepsnavbarModule as ɵb, StepsnvabarComponent as ɵc, ManageprofilesComponent as ɵd, ManageprofilesService as ɵe, ContentModule as ɵf, ContentComponent as ɵg, ContentsService as ɵh, FileUploadDirective as ɵi, AutosizeDirective as ɵj, ConfigurationModule as ɵk, ConfigurationComponent as ɵl, ConfigurationService as ɵm, SettingsComponent as ɵn, ResultspreviewComponent as ɵo, SaveprofileModule as ɵp, SaveprofileComponent as ɵq, SaveprofileService as ɵr, SaveProfileGuard as ɵs, UploadContentGuard as ɵt };
//# sourceMappingURL=interactiveminingv3.js.map
